'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

exports.default = createDhtSensor;

var _nodeDhtSensor = require('node-dht-sensor');

var _nodeDhtSensor2 = _interopRequireDefault(_nodeDhtSensor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function createDhtSensor(_ref) {
  var Service = _ref.Service,
      Characteristic = _ref.Characteristic;

  var CurrentRelativeHumidity = Characteristic.CurrentRelativeHumidity;
  var CurrentTemperature = Characteristic.CurrentTemperature;

  return function () {
    function DhtSensor(log, config) {
      var _this = this;

      _classCallCheck(this, DhtSensor);

      this.log = log;
      this.name = config.name;
      this.type = config.sensorType;
      this.pin = config.gpioPin;
      this.cacheTimeout = config.cacheTimeout || 60 * 1000; // 1 minute
      this.pollingInterval = config.pollingInterval || 5000;

      this.temperature = 0;
      this.humidity = 0;
      this.lastUpdate = null;

      this.humidityService = new Service.HumiditySensor(this.name);
      this.temperatureService = new Service.TemperatureSensor(this.name);

      this.humidityService.getCharacteristic(CurrentRelativeHumidity).on('get', this.getValue.bind(this, 'humidity'));
      this.temperatureService.getCharacteristic(CurrentTemperature).on('get', this.getValue.bind(this, 'temperature'));

      if (this.pollingInterval) {
        setInterval(function () {
          _this.getValue(null, function (err, values) {
            var _ref2 = values || {},
                humidity = _ref2.humidity,
                temperature = _ref2.temperature;

            if (err) {
              _this.log(err);
              return;
            }

            _this.humidityService.setCharacteristic(CurrentRelativeHumidity, humidity);
            _this.temperatureService.setCharacteristic(CurrentTemperature, temperature);
          });
        }, this.pollingInterval);
      }
    }

    _createClass(DhtSensor, [{
      key: 'getValue',
      value: function getValue(what, callback) {
        var _this2 = this;

        _nodeDhtSensor2.default.read(this.type, this.pin, function (err) {
          var temperature = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
          var humidity = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;

          if (!err && humidity !== 0 && temperature !== 0) {
            _this2.humidity = humidity;
            _this2.temperature = temperature;
            _this2.lastUpdate = Date.now();
          }

          if (Date.now() - _this2.lastUpdate >= _this2.cacheTimeout) {
            return callback(err || new Error('cannot get sensor data'), null);
          }

          switch (what) {
            case 'temperature':
              return callback(null, _this2.temperature);
            case 'humidity':
              return callback(null, _this2.humidity);
            default:
              return callback(null, { humidity: _this2.humidity, temperature: _this2.temperature });
          }
        });
      }
    }, {
      key: 'getServices',
      value: function getServices() {
        return [this.humidityService, this.temperatureService];
      }
    }]);

    return DhtSensor;
  }();
}